@@ -3,6 +3,11 @@ import numpy as np
 import pytest
 
 from plangym.atari import ale_to_ram, AtariEnvironment
+from tests import SKIP_ATARI_TESTS
+
+
+if SKIP_ATARI_TESTS:
+    pytest.skip("Atari not installed, skipping", allow_module_level=True)
 from tests.api_tests import batch_size, display, TestBaseEnvironment, TestGymEnvironment
 
 
