@@ -3,6 +3,8 @@ import os
 import numpy
 import pytest
 
+
+pytest.importorskip("dm_control")
 from plangym.dm_control import DMControlEnv
 from tests.api_tests import batch_size, display, TestBaseEnvironment, TestGymEnvironment
 
@@ -29,15 +31,21 @@ class TestDMControl:
         assert hasattr(env, "physics")
         assert hasattr(env, "action_spec")
         assert hasattr(env, "action_space")
+        assert hasattr(env, "render_mode")
+        assert env.render_mode in {"human", "rgb_array", None}
 
-    @pytest.mark.skipif(bool(os.getenv("SKIP_RENDER", False)), reason="No display in CI.")
+    @pytest.mark.skipif(os.getenv("SKIP_RENDER", False), reason="No display in CI.")
     def test_render(self, env):
         env.reset()
         obs_rgb = env.render(mode="rgb_array")
         assert isinstance(obs_rgb, numpy.ndarray)
         old_len = len(env.viewer)
-        asp = env.action_space
         action = env.sample_action()
         env.step(action)
         env.render(mode="human")
         assert len(env.viewer) > old_len
+        env.show_game(sleep=0.01)
+
+    def test_parse_name_fails(self):
+        with pytest.raises(ValueError):
+            DMControlEnv(name="cartpole")
